@@ -10,11 +10,12 @@
 
 #include <kxmlgui_export.h>
 
+#include <QList>
 #include <QObject>
 #include <QString>
-#include <QList>
+#include <memory>
 
-#include <kstandardaction.h>
+#include <KStandardAction>
 
 #include "kactioncollection.h"
 
@@ -57,7 +58,7 @@ class QAction;
  *
  * The synchronization between KActionCollection and KActionCategory is done
  * internally. There is for example no need to remove actions from a category.
- * It is done implicitely if the action is removed from the associated
+ * It is done implicitly if the action is removed from the associated
  * collection.
  *
  * \code
@@ -87,7 +88,6 @@ class KXMLGUI_EXPORT KActionCategory : public QObject
     Q_PROPERTY(QString text READ text WRITE setText)
 
 public:
-
     /**
      * Default constructor
      */
@@ -109,27 +109,14 @@ public:
     //@{
     QAction *addAction(const QString &name, QAction *action);
 
-    QAction *addAction(
-        KStandardAction::StandardAction actionType,
-        const QObject *receiver = nullptr,
-        const char *member = nullptr);
+    QAction *addAction(KStandardAction::StandardAction actionType, const QObject *receiver = nullptr, const char *member = nullptr);
 
-    QAction *addAction(
-        KStandardAction::StandardAction actionType,
-        const QString &name,
-        const QObject *receiver = nullptr,
-        const char *member = nullptr);
+    QAction *addAction(KStandardAction::StandardAction actionType, const QString &name, const QObject *receiver = nullptr, const char *member = nullptr);
 
-    QAction *addAction(
-        const QString &name,
-        const QObject *receiver = nullptr,
-        const char *member = nullptr);
+    QAction *addAction(const QString &name, const QObject *receiver = nullptr, const char *member = nullptr);
 
     template<class ActionType>
-    ActionType *add(
-        const QString &name,
-        const QObject *receiver = nullptr,
-        const char *member = nullptr)
+    ActionType *add(const QString &name, const QObject *receiver = nullptr, const char *member = nullptr)
     {
         ActionType *action = collection()->add<ActionType>(name, receiver, member);
         addAction(action);
@@ -140,7 +127,7 @@ public:
 
     /**
      * Returns the actions belonging to this category
-      */
+     */
     const QList<QAction *> actions() const;
 
     /**
@@ -159,7 +146,6 @@ public:
     void setText(const QString &text);
 
 private:
-
     /**
      * Remove \action from this category if found.
      */
@@ -170,11 +156,12 @@ private:
      */
     void addAction(QAction *action);
 
+private:
     //! KActionCollection needs access to some of our helper methods
     friend class KActionCollectionPrivate;
 
     //! Implementation details
-    KActionCategoryPrivate *const d;
+    std::unique_ptr<KActionCategoryPrivate> const d;
 };
 
 #endif /* #ifndef KACTIONCATEGORY_H */
